import json
import logging
import sys
from datetime import datetime

from postgres.client.sql import SQLit


class Experiment:

    def __init__(self):
        self.sqlit = SQLit()
        self.log = logging.getLogger(__name__)

    def deleteExperiment(self, filename):
        return self.sqlit.delete('experiments', 'filename', filename)

    def getExperiments(self, limit=None, offset=0, **filter):
        return self.sqlit.select_as_dict(
                'experiments',
                sort='filename',
                limit=limit,
                offset=offset,
                **filter)

    def getExperiment(self, filename):
        records = self.sqlit.select_as_dict(
            table='experiments',
            fetch=['data'],
            filename=filename
            )
        return records[0]['data']

    def getExperimentRec(self, filename):
        records = self.sqlit.select_as_dict(
            table='experiments',
            filename=filename
            )
        return records[0]


    def getExperimentsAsDict(self):
        records = self.sqlit.select_as_dict(
            table='experiments',
            sort='filename asc'
        )
        exp_as_dict = dict()
        for rec in records:
            exp_as_dict[rec['filename']] = rec
        return exp_as_dict

    def postExperiment(self, **attrs):
        if 'filename' not in attrs:
            self.log.error("filename missing")
            return None
        self.log.info("Adding experiment {}".format(attrs['filename']))
        try:
            for key in attrs:
                attrs[key] = json.dumps(attrs[key]) if isinstance(attrs[key], dict) else attrs[key]
            stmt = self.sqlit.insert_stmt('experiments', attrs)
            return self.sqlit.execute(stmt, *list(attrs.values()))
        except Exception as err:
            self.log.error("Error adding an experiment: {}".format(err))
            return None
        except:
            print("Unexpected error:", sys.exc_info()[0])  
            return None

    def updateExperiment(self, filename, data):    
        return self.sqlit.update('experiments', 'filename', filename, data=json.dumps(data))
