from postgres.client.sql import SQLit

class K8sResource:

    def __init__(self):
        self.sqlit = SQLit()

    def add_resource( self, resource: dict ):
        stmt = self.sqlit.insert_stmt('k8s_resources', resource)
        return self.sqlit.execute(stmt, *list(resource.values()))

    def update_resource_status(self, id, updated_status):
        return self.sqlit.update('k8s_resources','id',id, status=updated_status)

    def get_resources(self, limit=1000, offset=0, **filter):
        return self.sqlit.select_as_dict('k8s_resources', limit=limit, offset=offset,
                **filter)

    def get_resources_of_kind( self, kind, limit=1000, offset=0 ):
        count = limit

        if not offset:
            sql = "SELECT count(*) from k8s_resources where kind = %s;"
            recs = self.sqlit.execute(sql, (kind,))
            count = recs[0][0]

        cmd = """
            SELECT * FROM k8s_resources 
                WHERE kind = %s
                ORDER BY name DESC
                LIMIT %s
                OFFSET %s
            """
        return {
                "count": count,
                "records": self.sqlit.execute(cmd, kind, limit, offset)
        }


    def get_children( self, parent_id ):
        pass


