import logging
from postgres.client.sql import SQLit


class Resource:

    def __init__(self):
        self.sqlit = SQLit()
        self.logger = logging.getLogger(__name__)

    def get_tree(self, **filter):
        root = dict()
        root_rec = self.sqlit.select_as_dict(
            table='resources',
            fetch=[
                'id',
                'parent_id',
                'kind',
                'name',
                'creation_time',
                'last_updated',
                'layer',
                'tag',
                'status'
           ],
            **filter
        )
        if root_rec is not None:
            root = root_rec[0]
            self.logger.debug(f"Root: {root}")
            root['children'] = list()
            self.add_children(root)
        else:
            self.logger.error("No root element found")
        return root

    def add_children(self, parent):
        children = self.sqlit.select_as_dict(
            table='resources',
            fetch=[
                'id',
                'parent_id',
                'kind',
                'name',
                'creation_time',
                'last_updated',
                'layer',
                'tag',
                'status'
            ],
            **{'parent_id': parent['id']}
        )
        for child in children:
            child['children'] = list()
            self.add_children(child)
            parent['children'].append(child)
            self.logger.debug(f"Child {child} added to tree")

